[−][src]Enum rustorm::Value
Generic value storage 32 byte in size Some contains the same value container, but the variant is more important for type hinting and view presentation hinting purposes
Variants
NilBool(bool)Tinyint(i8)Smallint(i16)Int(i32)Bigint(i64)Float(f32)Double(f64)BigDecimal(BigDecimal)Blob(Vec<u8>)ImageUri(String)Char(char)Text(String)Json(String)Uuid(Uuid)Date(NaiveDate)Time(NaiveTime)DateTime(NaiveDateTime)Timestamp(DateTime<Utc>)Interval(Interval)Point(Point<f64>)Array(Array)Methods
impl Value[src]
impl ValueTrait Implementations
impl Clone for Value[src]
impl Clone for Valuefn clone(&self) -> Value[src]
fn clone(&self) -> Valuefn clone_from(&mut self, source: &Self)1.0.0[src]
fn clone_from(&mut self, source: &Self)Performs copy-assignment from source. Read more
impl Serialize for Value[src]
impl Serialize for Valuefn serialize<__S>(
&self,
__serializer: __S
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error> where
__S: Serializer, [src]
fn serialize<__S>(
&self,
__serializer: __S
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error> where
__S: Serializer, impl<'de> Deserialize<'de> for Value[src]
impl<'de> Deserialize<'de> for Valuefn deserialize<__D>(
__deserializer: __D
) -> Result<Value, <__D as Deserializer<'de>>::Error> where
__D: Deserializer<'de>, [src]
fn deserialize<__D>(
__deserializer: __D
) -> Result<Value, <__D as Deserializer<'de>>::Error> where
__D: Deserializer<'de>, impl<'a> From<&'a Option<String>> for Value[src]
impl<'a> From<&'a Option<String>> for Valuefor borrowed option types
impl From<Vec<u8>> for Value[src]
impl From<Vec<u8>> for ValueOwned types
impl<'a> From<&'a str> for Value[src]
impl<'a> From<&'a str> for Valueimpl From<DateTime<Utc>> for Value[src]
impl From<DateTime<Utc>> for ValueOwned types
impl<'a> From<&'a bool> for Value[src]
impl<'a> From<&'a bool> for ValueFor borrowed types
impl<'a> From<&'a NaiveDate> for Value[src]
impl<'a> From<&'a NaiveDate> for ValueFor borrowed types
impl From<i8> for Value[src]
impl From<i8> for ValueOwned types
impl<'a> From<&'a char> for Value[src]
impl<'a> From<&'a char> for ValueFor borrowed types
impl<'a> From<&'a Option<f64>> for Value[src]
impl<'a> From<&'a Option<f64>> for Valuefor borrowed option types
impl<'a> From<&'a Option<i32>> for Value[src]
impl<'a> From<&'a Option<i32>> for Valuefor borrowed option types
impl From<Vec<String>> for Value[src]
impl From<Vec<String>> for Valueimpl From<i64> for Value[src]
impl From<i64> for ValueOwned types
impl From<String> for Value[src]
impl From<String> for ValueOwned types
impl From<NaiveDate> for Value[src]
impl From<NaiveDate> for ValueOwned types
impl<'a> From<&'a Option<i16>> for Value[src]
impl<'a> From<&'a Option<i16>> for Valuefor borrowed option types
impl From<Uuid> for Value[src]
impl From<Uuid> for ValueOwned types
impl<'a> From<&'a Option<char>> for Value[src]
impl<'a> From<&'a Option<char>> for Valuefor borrowed option types
impl<'a> From<&'a f32> for Value[src]
impl<'a> From<&'a f32> for ValueFor borrowed types
impl<'a> From<&'a DateTime<Utc>> for Value[src]
impl<'a> From<&'a DateTime<Utc>> for ValueFor borrowed types
impl<'a> From<&'a Option<NaiveDate>> for Value[src]
impl<'a> From<&'a Option<NaiveDate>> for Valuefor borrowed option types
impl<'a> From<&'a Option<Uuid>> for Value[src]
impl<'a> From<&'a Option<Uuid>> for Valuefor borrowed option types
impl From<i16> for Value[src]
impl From<i16> for ValueOwned types
impl From<i32> for Value[src]
impl From<i32> for ValueOwned types
impl<'a> From<&'a Uuid> for Value[src]
impl<'a> From<&'a Uuid> for ValueFor borrowed types
impl<'a> From<&'a Option<Vec<u8>>> for Value[src]
impl<'a> From<&'a Option<Vec<u8>>> for Valuefor borrowed option types
impl<'a> From<&'a Option<bool>> for Value[src]
impl<'a> From<&'a Option<bool>> for Valuefor borrowed option types
impl<'a> From<&'a f64> for Value[src]
impl<'a> From<&'a f64> for ValueFor borrowed types
impl<'a> From<&'a Option<DateTime<Utc>>> for Value[src]
impl<'a> From<&'a Option<DateTime<Utc>>> for Valuefor borrowed option types
impl<'a> From<&'a Option<f32>> for Value[src]
impl<'a> From<&'a Option<f32>> for Valuefor borrowed option types
impl<'a> From<&'a Vec<u8>> for Value[src]
impl<'a> From<&'a Vec<u8>> for ValueFor borrowed types
impl<'a> From<&'a i32> for Value[src]
impl<'a> From<&'a i32> for ValueFor borrowed types
impl From<f32> for Value[src]
impl From<f32> for ValueOwned types
impl<'a> From<&'a Option<i64>> for Value[src]
impl<'a> From<&'a Option<i64>> for Valuefor borrowed option types
impl<'a> From<&'a Option<NaiveTime>> for Value[src]
impl<'a> From<&'a Option<NaiveTime>> for Valuefor borrowed option types
impl<'a> From<&'a NaiveTime> for Value[src]
impl<'a> From<&'a NaiveTime> for ValueFor borrowed types
impl<'a> From<&'a String> for Value[src]
impl<'a> From<&'a String> for ValueFor borrowed types
impl From<bool> for Value[src]
impl From<bool> for ValueOwned types
impl<'a> From<&'a Option<i8>> for Value[src]
impl<'a> From<&'a Option<i8>> for Valuefor borrowed option types
impl From<char> for Value[src]
impl From<char> for ValueOwned types
impl From<f64> for Value[src]
impl From<f64> for ValueOwned types
impl From<NaiveTime> for Value[src]
impl From<NaiveTime> for ValueOwned types
impl<'a> From<&'a i64> for Value[src]
impl<'a> From<&'a i64> for ValueFor borrowed types
impl<'a> From<&'a i16> for Value[src]
impl<'a> From<&'a i16> for ValueFor borrowed types
impl<'a> From<&'a Vec<String>> for Value[src]
impl<'a> From<&'a Vec<String>> for Valueimpl<'a> From<&'a i8> for Value[src]
impl<'a> From<&'a i8> for ValueFor borrowed types
impl Debug for Value[src]
impl Debug for Valueimpl PartialEq<Value> for Value[src]
impl PartialEq<Value> for ValueAuto Trait Implementations