Pool

Struct Pool 

pub struct Pool(/* private fields */);

Implementations

Source

impl Pool

pub fn new() -> Self

pub fn ensure(&mut self, db_url: &str) -> Result<(), DbError>

ensure that a connection pool for this db_url exist

Note: if that db_url already has an equivalent connection pool, this doesn’t do anything

pub fn connect(&mut self, db_url: &str) -> Result<PooledConn, DbError>

get a usable database connection from

pub fn dm(&mut self, db_url: &str) -> Result<DaoManager, DbError>

returns a dao manager which provides api which data is already converted into Dao, Rows and Value

pub fn connect_mut(&mut self, db_url: &str) -> Result<PooledConn, DbError>

get a usable database connection from

pub fn db(&mut self, db_url: &str) -> Result<DBPlatform, DbError>

get a database instance with a connection, ready to send sql statements

pub fn em(&mut self, db_url: &str) -> Result<EntityManager, DbError>

return an entity manager which provides a higher level api